@@ -216,9 +216,9 @@ def sync_customer(name, product_name, refnum):
     exists = get_customers_si(
         identifier="name",
         value=name
-    )[0]
+    )
     if exists:
-        if exists['refnum'] != refnum or exists['product'] != product_name:
+        if exists[0]['refnum'] != refnum or exists[0]['product'] != product_name:
             update_customer(name, product_name, refnum)
     else:
         create_customer(name, product_name, refnum)
